@@ -25,13 +25,16 @@
 #include <string.h>
 
 #include "preferences.h"
-#include "command_line.h"
+#include "command_line.h" /* needed for style changes */
+#include "history.h"
 #include "message.h"
 #include "mini-commander_applet.h"
 
 /* properties prop = { TRUE, TRUE, 11, 12, 13, 14, 15, 0, 0, 0, 50000, 50000, 50000 }; */
 /* properties propTmp = { -1, -1, -1, -1, -1, -1, -1 -1, -1, -1, -1, -1, -1}; */
 
+static void resetTemporaryPrefs(void);
+
 properties prop;
 properties propTmp;
 
@@ -79,21 +82,39 @@ colorCmdBgChanged_signal(GtkWidget *colorPickerWidget, gpointer *data)
     propTmp.cmdLineColorBgB = (int) b;
 }
 
+static void
+resetTemporaryPrefs(void)
+{
+    /* reset temporary prefereces */
+    propTmp.showTime = -1;
+    propTmp.showDate = -1;
+    propTmp.normalSizeX = -1;
+    propTmp.normalSizeY = -1;
+    propTmp.reducedSizeX = -1;
+    propTmp.reducedSizeY = -1;
+    propTmp.cmdLineY = -1;
+    propTmp.cmdLineColorFgR = -1;
+    propTmp.cmdLineColorFgG = -1;
+    propTmp.cmdLineColorFgB = -1;
+    propTmp.cmdLineColorBgR = -1;
+    propTmp.cmdLineColorBgG = -1;
+    propTmp.cmdLineColorBgB = -1;
+}
+
+
 static void
 propertiesBox_apply_signal(GnomePropertyBox *propertyBoxWidget, gint page, gpointer data)
 {
     GtkStyle *style;
     int i;
 
-    if(propTmp.showTime != -1) {
+    if(propTmp.showTime != -1)
 	/* checkbox has been changed */
 	prop.showTime = propTmp.showTime;
-    }
 
-    if(propTmp.showTime != -1 || propTmp.showDate != -1) {
+    if(propTmp.showDate != -1)
 	/* checkbox has been changed */
 	prop.showDate = propTmp.showDate;
-    }
 
     if(propTmp.showTime != -1 || propTmp.showDate != -1) {
 	/* checkbox has been changed */
@@ -105,9 +126,6 @@ propertiesBox_apply_signal(GnomePropertyBox *propertyBoxWidget, gint page, gpoin
 	    showMessage((gchar *) _("date on")); 
 	else
 	    showMessage((gchar *) _("clock off")); 
-	
-	propTmp.showTime = -1;
-	propTmp.showDate = -1;
     }
 
     if(propTmp.normalSizeX != -1)
@@ -138,12 +156,6 @@ propertiesBox_apply_signal(GnomePropertyBox *propertyBoxWidget, gint page, gpoin
     if(propTmp.cmdLineY != -1)
 	gtk_widget_set_usize(GTK_WIDGET(entryCommand), -1, prop.cmdLineY);
 
-    propTmp.normalSizeX = -1;
-    propTmp.normalSizeY = -1;
-    propTmp.reducedSizeX = -1;
-    propTmp.reducedSizeY = -1;
-    propTmp.cmdLineY = -1;
-
     /* colors */
     if(propTmp.cmdLineColorFgR != -1)
 	{
@@ -175,14 +187,7 @@ propertiesBox_apply_signal(GnomePropertyBox *propertyBoxWidget, gint page, gpoin
 	    gtk_widget_set_style(entryCommand, style);
 	}
 
-    propTmp.cmdLineColorFgR = -1;
-    propTmp.cmdLineColorFgG = -1;
-    propTmp.cmdLineColorFgB = -1;
-    propTmp.cmdLineColorBgR = -1;
-    propTmp.cmdLineColorBgG = -1;
-    propTmp.cmdLineColorBgB = -1;
-
-    /* prefix & command */
+    /* macros */
     for(i=0; i<=MAX_PREFIXES-1; i++)
 	{
 	    if (propTmp.prefix[i] != (char *) NULL)
@@ -200,6 +205,7 @@ propertiesBox_apply_signal(GnomePropertyBox *propertyBoxWidget, gint page, gpoin
 		}
 	}    
 
+    resetTemporaryPrefs();
 
     /*    gtk_widget_queue_resize(applet); */
 
@@ -223,7 +229,7 @@ loadSession(void)
     prop.showDate = gnome_config_get_bool("mini_commander/show_date=false");
 
     /* size */
-    prop.normalSizeX = gnome_config_get_int("mini_commander/normal_size_x=128");
+    prop.normalSizeX = gnome_config_get_int("mini_commander/normal_size_x=148");
     prop.normalSizeY = gnome_config_get_int("mini_commander/normal_size_y=48");
     prop.reducedSizeX = gnome_config_get_int("mini_commander/reduced_size_x=50");
     prop.reducedSizeY = gnome_config_get_int("mini_commander/reduced_size_y=48");
@@ -238,11 +244,11 @@ loadSession(void)
     prop.cmdLineColorBgG = gnome_config_get_int("mini_commander/cmd_line_color_bg_g=0");
     prop.cmdLineColorBgB = gnome_config_get_int("mini_commander/cmd_line_color_bg_b=0");
 
-
+    /* macros */
     for(i=0; i<=MAX_PREFIXES-1; i++)
 	{
 	    switch (i+1) 
-		/* set default prefixes */
+		/* set default macros */
 		{
 		case 1:
 		    strcpy(defaultPrefix, "http://");
@@ -258,15 +264,15 @@ loadSession(void)
 		    break;
 		case 4:
 		    strcpy(defaultPrefix, "ftp.");
-		    strcpy(defaultCommand, "netscape -remote openURL\\(ftp.://$1\\) || netscape ftp://ftp.$1");
+		    strcpy(defaultCommand, "netscape -remote openURL\\(ftp.://ftp.$1\\) || netscape ftp://ftp.$1");
 		    break;
 		case 5:
 		    strcpy(defaultPrefix, "lynx:");
-		    strcpy(defaultCommand, "gnome-terminal -e sh -c 'lynx $1'");
+		    strcpy(defaultCommand, "gnome-terminal -e \"sh -c 'lynx $1'\"");
 		    break;
 		case 6:
 		    strcpy(defaultPrefix, "term:");
-		    strcpy(defaultCommand, "gnome-terminal -e sh -c '$1'");
+		    strcpy(defaultCommand, "gnome-terminal -e \"sh -c '$1'\"");
 		    break;
 		case 7:
 		    strcpy(defaultPrefix, "xterm:");
@@ -309,6 +315,14 @@ loadSession(void)
 	    propTmp.command[i] = (char *) NULL;
 	}    
 
+    /* history */
+    for(i = 0; i < HISTORY_DEPTH; i++)
+	{
+	    g_snprintf(section, sizeof(section), "mini_commander/history_%d=%s", i, "");
+	    if(strcmp("", (char *) gnome_config_get_string((gchar *) section)) != 0)
+	       appendHistoryEntry(gnome_config_get_string((gchar *) section));
+	}
+
     gnome_config_pop_prefix();
 }
 
@@ -320,6 +334,7 @@ saveSession(void)
     char section[100];
 
     /* gnome_config_push_prefix(globcfgpath); */
+    /* all instances of mini-commander use the same global settings */
     gnome_config_push_prefix("/mini-commander/"); 
 
     /* version */
@@ -345,7 +360,7 @@ saveSession(void)
     gnome_config_set_int("mini_commander/cmd_line_color_bg_g", prop.cmdLineColorBgG);
     gnome_config_set_int("mini_commander/cmd_line_color_bg_b", prop.cmdLineColorBgB);
 
-    /* prefix & command */
+    /* macros */
     for(i=0; i<=MAX_PREFIXES-1; i++)
 	{
 	    g_snprintf(section, sizeof(section), "mini_commander/prefix_%d", i+1);
@@ -358,20 +373,21 @@ saveSession(void)
 	    propTmp.command[i] = (char *) NULL;
 	}    
 
+    /* history */
+    for(i = 0; i < HISTORY_DEPTH; i++)
+	{
+	    g_snprintf(section, sizeof(section), "mini_commander/history_%d", i);
+	    if(existsHistoryEntry(i))
+		gnome_config_set_string((gchar *) section, (gchar *) getHistoryEntry(i));
+	    else
+		gnome_config_set_string((gchar *) section, (gchar *) "");
+	}
   
     gnome_config_sync();
     /* you need to use the drop_all here since we're all writing to
        one file, without it, things might not work too well */
     gnome_config_drop_all();
     
-    /* make sure you return FALSE, otherwise your applet might not
-       work compeltely, there are very few circumstances where you
-       want to return TRUE. This behaves similiar to GTK events, in
-       that if you return FALSE it means that you haven't done
-       everything yourself, meaning you want the panel to save your
-       other state such as the panel you are on, position,
-       parameter, etc ... */
-
     gnome_config_pop_prefix(); 
 }
 
@@ -381,12 +397,20 @@ saveSession_signal(GtkWidget *widget, const char *privcfgpath, const char *globc
     showMessage((gchar *) _("saving prefs...")); 	    
     saveSession();
 
+    /* make sure you return FALSE, otherwise your applet might not
+       work compeltely, there are very few circumstances where you
+       want to return TRUE. This behaves similiar to GTK events, in
+       that if you return FALSE it means that you haven't done
+       everything yourself, meaning you want the panel to save your
+       other state such as the panel you are on, position,
+       parameter, etc ... */
     return FALSE;
 }
 
 void
 propertiesBox(AppletWidget *applet, gpointer data)
 {
+    static GnomeHelpMenuEntry helpEntry = { NULL,  "properties" };
     GtkWidget *propertiesBox;
     GtkWidget *vbox, *vbox1, *frame;
     GtkWidget *hbox, *hbox1;
@@ -395,23 +419,13 @@ propertiesBox(AppletWidget *applet, gpointer data)
     GtkWidget *label;
     GtkWidget *entry;
     GtkWidget *colorPicker;
+    GtkWidget *scrolledWindow;
     char textLabel[50], buffer[50];
     int i, j;
 
-    /* reset temporary prefereces */
-    propTmp.showTime = -1;
-    propTmp.showDate = -1;
-    propTmp.normalSizeX = -1;
-    propTmp.normalSizeY = -1;
-    propTmp.reducedSizeX = -1;
-    propTmp.reducedSizeY = -1;
-    propTmp.cmdLineY = -1;
-    propTmp.cmdLineColorFgR = -1;
-    propTmp.cmdLineColorFgG = -1;
-    propTmp.cmdLineColorFgB = -1;
-    propTmp.cmdLineColorBgR = -1;
-    propTmp.cmdLineColorBgG = -1;
-    propTmp.cmdLineColorBgB = -1;
+    helpEntry.name = gnome_app_id;
+
+    resetTemporaryPrefs();
 
     propertiesBox = gnome_property_box_new();
     
@@ -419,18 +433,18 @@ propertiesBox(AppletWidget *applet, gpointer data)
     
     /* time & date */
     vbox = gtk_vbox_new(FALSE, GNOME_PAD_BIG);
-    gtk_container_border_width(GTK_CONTAINER(vbox), GNOME_PAD_SMALL);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD_SMALL);
 
     frame = gtk_frame_new(_("Clock"));
     gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
     vbox1 = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-    gtk_container_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
     gtk_container_add(GTK_CONTAINER(frame), vbox1);
 
     /* show time check box */
     checkTime = gtk_check_button_new_with_label (_("Show time"));
-    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(checkTime), prop.showTime);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkTime), prop.showTime);
     gtk_signal_connect(GTK_OBJECT(checkTime),
 		       "toggled",
 		       GTK_SIGNAL_FUNC(checkBoxToggled_signal),
@@ -443,7 +457,7 @@ propertiesBox(AppletWidget *applet, gpointer data)
     /* show date check box */
 
     checkDate = gtk_check_button_new_with_label (_("Show date"));
-    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(checkDate), prop.showDate);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkDate), prop.showDate);
     gtk_signal_connect(GTK_OBJECT(checkDate),
 		       "toggled",
 		       GTK_SIGNAL_FUNC(checkBoxToggled_signal),
@@ -462,7 +476,7 @@ propertiesBox(AppletWidget *applet, gpointer data)
     /*    gtk_table_set_row_spacing(GTK_TABLE(table), 1, GNOME_PAD_SMALL); 
 	  gtk_table_set_row_spacing(GTK_TABLE(table), 2, 20);  */ /* no effect? */
     gtk_table_set_col_spacings(GTK_TABLE(table), GNOME_PAD_SMALL);
-    gtk_container_border_width(GTK_CONTAINER(table), GNOME_PAD_SMALL);
+    gtk_container_set_border_width(GTK_CONTAINER(table), GNOME_PAD_SMALL);
     gtk_container_add(GTK_CONTAINER(frame), table);
 
     /* applet width */    
@@ -570,7 +584,7 @@ propertiesBox(AppletWidget *applet, gpointer data)
     table = gtk_table_new(2, 2, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), GNOME_PAD_SMALL);
     gtk_table_set_col_spacings(GTK_TABLE(table), GNOME_PAD_SMALL);
-    gtk_container_border_width(GTK_CONTAINER(table), GNOME_PAD_SMALL);
+    gtk_container_set_border_width(GTK_CONTAINER(table), GNOME_PAD_SMALL);
     gtk_container_add(GTK_CONTAINER(frame), table);
 
     /* fg */
@@ -646,76 +660,77 @@ propertiesBox(AppletWidget *applet, gpointer data)
 
 
 
-    /*Prefixes */
-    for(j=0; j<3; j++)
+    /* Macros */   
+    frame = gtk_frame_new((gchar *) NULL);
+
+    gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL); 
+    
+    scrolledWindow = gtk_scrolled_window_new(NULL, NULL);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledWindow),
+				   GTK_POLICY_AUTOMATIC,
+				   GTK_POLICY_AUTOMATIC);
+    gtk_container_set_border_width(GTK_CONTAINER(scrolledWindow), GNOME_PAD_SMALL); 
+    gtk_container_add(GTK_CONTAINER(frame), scrolledWindow); 
+
+    vbox1 = gtk_vbox_new(TRUE, GNOME_PAD_SMALL);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
+    /* gtk_container_add(GTK_CONTAINER(scrolledWindow), vbox1); does not work */
+    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolledWindow), vbox1);
+
+    for(i=0; i < MAX_PREFIXES; i++)
 	{
-	    vbox = gtk_vbox_new(FALSE, GNOME_PAD_BIG);
-	    gtk_container_border_width(GTK_CONTAINER(vbox), GNOME_PAD_SMALL);
+	    hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+  	    gtk_box_pack_start(GTK_BOX(vbox1), hbox, TRUE, TRUE, 0);   
 	    
-	    frame = gtk_frame_new(_("Special Prefixes"));
-	    gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
+	    /* prefix */    
+	    g_snprintf(textLabel, sizeof(textLabel), _("Prefix %.2d:"), i+1);
+	    gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(textLabel), FALSE, TRUE, 0);
 	    
-	    vbox1 = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-	    gtk_container_border_width(GTK_CONTAINER(vbox1), GNOME_PAD_SMALL);
-	    gtk_container_add(GTK_CONTAINER(frame), vbox1);
+	    entry = gtk_entry_new_with_max_length(MAX_PREFIX_LENGTH);
+	    gtk_widget_set_usize(entry, 75, -1);
+	    if (prop.prefix[i] != (gchar *) NULL)
+		gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) prop.prefix[i]);
+	    gtk_signal_connect(GTK_OBJECT(entry),
+			       "changed",
+			       GTK_SIGNAL_FUNC(entryChanged_signal),
+			       &propTmp.prefix[i]);
+	    gtk_signal_connect_object(GTK_OBJECT(entry),
+				      "changed",
+				      GTK_SIGNAL_FUNC(gnome_property_box_changed),
+				      GTK_OBJECT(propertiesBox));      
+	    gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, TRUE, 0);
 	    
-	    /*    gtk_box_pack_start(GTK_BOX(vbox1),
-		  gtk_label_new((gchar *) _("HGjshd ajhs djah dkjha sjhd akjshda jshdajks dhjkashd ahjshd ajkshd ajkshd jkashdjkas hdjkas hdjkashd jhasd jkashdjkh.")), 
-		  FALSE, 
-		  FALSE, 
-		  0); */
+	    /* command */
+	    g_snprintf(textLabel, sizeof(textLabel), _("   Macro %.2d:"), i+1);
+	    gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(textLabel), FALSE, TRUE, 0);
 	    
-	    for(i=(MAX_PREFIXES/3)*j; i<=(MAX_PREFIXES/3)*(j+1)-1; i++)
-		{
-		    hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-		    gtk_box_pack_start(GTK_BOX(vbox1), hbox, TRUE, TRUE, 0);
-		    
-		    /* prefix */    
-		    g_snprintf(textLabel, sizeof(textLabel), _("Prefix %.2d:"), i+1);
-		    gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(textLabel), FALSE, TRUE, 0);
-		    
-		    entry = gtk_entry_new_with_max_length(MAX_PREFIX_LENGTH);
-		    gtk_widget_set_usize(entry, 75, -1);
-		    if (prop.prefix[i] != (gchar *) NULL)
-			gtk_entry_set_text(GTK_ENTRY(entry), (gchar *) prop.prefix[i]);
-		    gtk_signal_connect(GTK_OBJECT(entry),
-				       "changed",
-				       GTK_SIGNAL_FUNC(entryChanged_signal),
-				       &propTmp.prefix[i]);
-		    gtk_signal_connect_object(GTK_OBJECT(entry),
-					      "changed",
-					      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-					      GTK_OBJECT(propertiesBox));      
-		    gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, TRUE, 0);
-		    
-		    /* command */
-		    g_snprintf(textLabel, sizeof(textLabel), _("   Command %.2d:"), i+1);
-		    gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(textLabel), FALSE, TRUE, 0);
-		    
-		    entry = gtk_entry_new_with_max_length(MAX_COMMAND_LENGTH);
-		    if (prop.command[i] != (gchar *) NULL)
-			gtk_entry_set_text(GTK_ENTRY(entry), prop.command[i]);
-		    gtk_signal_connect(GTK_OBJECT(entry),
-				       "changed",
-				       GTK_SIGNAL_FUNC(entryChanged_signal),
-				       &propTmp.command[i]);
-		    gtk_signal_connect_object(GTK_OBJECT(entry),
-					      "changed",
-					      GTK_SIGNAL_FUNC(gnome_property_box_changed),
-					      GTK_OBJECT(propertiesBox));  
-		    gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
-		}
-	    
-	    g_snprintf(textLabel, sizeof(textLabel), _("Prefixes %d"), j+1);
-	    gnome_property_box_append_page(GNOME_PROPERTY_BOX(propertiesBox),
-					   vbox,
-					   gtk_label_new((gchar *) textLabel));
+	    entry = gtk_entry_new_with_max_length(MAX_COMMAND_LENGTH);
+	    if (prop.command[i] != (gchar *) NULL)
+		gtk_entry_set_text(GTK_ENTRY(entry), prop.command[i]);
+	    gtk_signal_connect(GTK_OBJECT(entry),
+			       "changed",
+			       GTK_SIGNAL_FUNC(entryChanged_signal),
+			       &propTmp.command[i]);
+	    gtk_signal_connect_object(GTK_OBJECT(entry),
+				      "changed",
+				      GTK_SIGNAL_FUNC(gnome_property_box_changed),
+				      GTK_OBJECT(propertiesBox));  
+	    gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
 	}
 
+    gnome_property_box_append_page(GNOME_PROPERTY_BOX(propertiesBox),
+				   frame,
+				   gtk_label_new((gchar *) _("Macros")));
+
     gtk_signal_connect(GTK_OBJECT(propertiesBox), 
 		       "apply",
 		       GTK_SIGNAL_FUNC(propertiesBox_apply_signal),
 		       NULL);
+
+    gtk_signal_connect(GTK_OBJECT(propertiesBox),
+		       "help",
+		       GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+		       &helpEntry);
     
     gtk_widget_show_all(propertiesBox);
 }
