@@ -124,7 +124,21 @@ typedef struct {
 	int changed;
 } preferences_t;
 
-static void new_terminal (GtkWidget *widget, ZvtTerm *term);
+/*
+ * Exported interfaces, for Gtk modules that hook
+ * into the gnome terminal
+ */
+void close_terminal_cmd   (void *unused, void *data);
+void save_preferences_cmd (GtkWidget *widget, ZvtTerm *term);
+void color_cmd            (void);
+void show_menu_cmd        (GtkWidget *widget, ZvtTerm *term);
+void hide_menu_cmd        (GtkWidget *widget, ZvtTerm *term);
+void paste_cmd            (GtkWidget *widget, ZvtTerm *term);
+void preferences_cmd      (GtkWidget *widget, ZvtTerm *term);
+
+GtkWidget *new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry);
+GtkWidget *new_terminal     (GtkWidget *widget, ZvtTerm *term);
+
 static void parse_an_arg (poptContext state,
 			  enum poptCallbackReason reason,
 			  const struct poptOption *opt,
@@ -169,7 +183,7 @@ close_app (GtkWidget *app)
 }
 
 
-static void
+void
 close_terminal_cmd (void *unused, void *data)
 {
 	GtkWidget *top = gtk_widget_get_toplevel (GTK_WIDGET (data));
@@ -543,7 +557,7 @@ apply_changes (ZvtTerm *term, struct terminal_config *newcfg)
 	return 0;
 }
 
-static void save_preferences_cmd (GtkWidget *widget, ZvtTerm *term);
+void save_preferences_cmd (GtkWidget *widget, ZvtTerm *term);
 
 static void
 apply_changes_cmd (GtkWidget *widget, int page, ZvtTerm *term)
@@ -869,7 +883,7 @@ save_preferences (GtkWidget *widget, ZvtTerm *term,
 	gnome_config_sync ();
 }
 
-static void
+void
 save_preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	struct terminal_config *cfg = 
@@ -881,7 +895,7 @@ save_preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gnome_config_pop_prefix ();
 }
 
-static void
+void
 preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
@@ -1226,7 +1240,7 @@ color_ok (GtkWidget *w)
 	gtk_widget_destroy (gtk_widget_get_toplevel (w));
 }
 
-static void
+void
 color_cmd (void)
 {
 	GtkWidget *c;
@@ -1240,7 +1254,7 @@ color_cmd (void)
 }
 #endif
 
-static void
+void
 show_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	GnomeApp *app;
@@ -1253,7 +1267,7 @@ show_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 	save_preferences_cmd (widget, term);
 }
 
-static void
+void
 hide_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	GnomeApp *app;
@@ -1266,7 +1280,22 @@ hide_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 	save_preferences_cmd (widget, term);
 }
 
+#ifdef HAVE_ZVT_TERM_RESET
 static void
+reset_terminal_soft_cmd (GtkWidget *widget, ZvtTerm *term)
+{
+	zvt_term_reset(term, 0);
+}
+
+/* could also possible clear the buffer? */
+static void
+reset_terminal_hard_cmd (GtkWidget *widget, ZvtTerm *term)
+{
+	zvt_term_reset(term, 1);
+}
+#endif
+
+void
 paste_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	GdkAtom string_atom;
@@ -1293,6 +1322,10 @@ static GnomeUIInfo gnome_terminal_popup_menu_hide [] = {
         GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),
         GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
 	GNOMEUIINFO_ITEM_NONE (N_("_Hide menubar"), NULL, hide_menu_cmd),
+#ifdef HAVE_ZVT_TERM_RESET
+	GNOMEUIINFO_ITEM_NONE (N_("_Reset Terminal"), NULL, reset_terminal_soft_cmd),
+	GNOMEUIINFO_ITEM_NONE (N_("Reset and _Clear"), NULL, reset_terminal_hard_cmd),
+#endif
 	GNOMEUIINFO_END
 };
 
@@ -1300,6 +1333,10 @@ static GnomeUIInfo gnome_terminal_popup_menu_show [] = {
         GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),
         GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
 	GNOMEUIINFO_ITEM_NONE (N_("_Show menubar"), NULL, show_menu_cmd),
+#ifdef HAVE_ZVT_TERM_RESET
+	GNOMEUIINFO_ITEM_NONE (N_("_Reset Terminal"), NULL, reset_terminal_soft_cmd),
+	GNOMEUIINFO_ITEM_NONE (N_("Reset and _Clear"), NULL, reset_terminal_hard_cmd),
+#endif
 	GNOMEUIINFO_END
 };
 
@@ -1316,6 +1353,10 @@ static GnomeUIInfo gnome_terminal_edit [] = {
 
 static GnomeUIInfo gnome_terminal_settings_menu [] = {
         GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
+#ifdef HAVE_ZVT_TERM_RESET
+	GNOMEUIINFO_ITEM_NONE (N_("_Reset Terminal"), NULL, reset_terminal_soft_cmd),
+	GNOMEUIINFO_ITEM_NONE (N_("Reset and _Clear"), NULL, reset_terminal_hard_cmd),
+#endif
 	GNOMEUIINFO_ITEM_NONE (N_("C_olor selector..."), NULL, color_cmd),
 	GNOMEUIINFO_END
 };
@@ -1570,7 +1611,7 @@ term_change_pos(GtkWidget *widget)
 		gtk_widget_queue_draw(widget);
 }
 
-static void
+GtkWidget *
 new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 {
 	GtkWidget *app, *hbox, *scrollbar;
@@ -1666,7 +1707,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	gtk_signal_connect_after (GTK_OBJECT (term), "size_allocate",
 				  GTK_SIGNAL_FUNC (size_allocate), term);
 	
-	gnome_app_create_menus_with_data (GNOME_APP (app), gnome_terminal_menu, term);
+	if (!cfg->menubar_hidden)
+		gnome_app_create_menus_with_data (GNOME_APP (app), gnome_terminal_menu, term);
 	
 	/* Decorations */
 	hbox = gtk_hbox_new (0, 0);
@@ -1726,9 +1768,11 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	 * We need to hide this here, because the gnome_app_show
 	 * method will force a show on the menu
 	 */
-	if (cfg->menubar_hidden)
+	if (cfg->menubar_hidden) {
+		gnome_app_create_menus_with_data (GNOME_APP (app), gnome_terminal_menu, term);
 		gtk_widget_hide (GNOME_APP (app)->menubar->parent);
-	
+	}
+
 	set_color_scheme (term, cfg);
 
 	gdk_window_set_hints (((GtkWidget *)app)->window,
@@ -1737,7 +1781,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	switch (zvt_term_forkpty (term, update_records)){
 	case -1:
 		perror ("Error: unable to fork");
-		return;
+		return NULL;
 		
 	case 0: {
 		int open_max = sysconf (_SC_OPEN_MAX);
@@ -1758,16 +1802,18 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	}
 
         /* IS THIS BEING DOUBLE-FREED??? --JMP g_free (shell); */
+
+	return app;
 }
 
-static void
+GtkWidget *
 new_terminal (GtkWidget *widget, ZvtTerm *term)
 {
 	struct terminal_config *cfg;
 
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 
-	new_terminal_cmd (NULL, cfg, NULL);
+	return new_terminal_cmd (NULL, cfg, NULL);
 }
 
 static gboolean
@@ -1938,8 +1984,8 @@ enum {
 static struct poptOption cb_options [] = {
 	{ NULL, '\0', POPT_ARG_CALLBACK, parse_an_arg, 0},
 
-	{ "class", '\0', POPT_ARG_STRING, NULL, CLASS_KEY,
-	  N_("Terminal class name"), N_("CLASS")},
+	{ "tclass", '\0', POPT_ARG_STRING, NULL, CLASS_KEY,
+	  N_("Terminal class name"), N_("TCLASS")},
 
 	{ "font", '\0', POPT_ARG_STRING, NULL, FONT_KEY,
 	  N_("Specifies font name"), N_("FONT")},
