@@ -164,43 +164,84 @@ corner_widget_get_hidepos(CornerWidget *corner, PanelOrientType *hide_orient,
 	if(corner->state == CORNER_SHOWN)
 		return;
 	
-	switch(corner->pos) {
-	case CORNER_NE:
-		if(panel->orient == PANEL_HORIZONTAL) {
-			*w = basep->hidebutton_w->allocation.width;
-			*hide_orient = ORIENT_RIGHT;
-		} else {
-			*h = basep->hidebutton_s->allocation.height;
-			*hide_orient = ORIENT_UP;
-		}
-		break;
-	case CORNER_SE:
-		if(panel->orient == PANEL_HORIZONTAL) {
-			*w = basep->hidebutton_w->allocation.width;
-			*hide_orient = ORIENT_RIGHT;
-		} else {
-			*h = basep->hidebutton_n->allocation.height;
-			*hide_orient = ORIENT_DOWN;
-		}
-		break;
-	case CORNER_SW:
-		if(panel->orient == PANEL_HORIZONTAL) {
-			*w = basep->hidebutton_e->allocation.width;
-			*hide_orient = ORIENT_LEFT;
-		} else {
-			*h = basep->hidebutton_n->allocation.height;
-			*hide_orient = ORIENT_DOWN;
-		}
-		break;
-	case CORNER_NW:
-		if(panel->orient == PANEL_HORIZONTAL) {
-			*w = basep->hidebutton_e->allocation.width;
-			*hide_orient = ORIENT_LEFT;
-		} else {
-			*h = basep->hidebutton_s->allocation.height;
-			*hide_orient = ORIENT_UP;
-		}
-		break;
+	if (corner->state == CORNER_AUTO_HIDDEN) {
+	        switch (corner->pos) {
+	        case CORNER_NE:
+	                if (panel->orient == PANEL_HORIZONTAL) {
+	                        *h = pw_minimized_size;
+	                        *hide_orient = ORIENT_UP;
+	                } else {
+	                        *w = pw_minimized_size;
+	                        *hide_orient = ORIENT_RIGHT;
+	                }
+	                break;
+	        case CORNER_SE:
+	                if (panel->orient == PANEL_HORIZONTAL) {
+	                        *h = pw_minimized_size;
+	                        *hide_orient = ORIENT_DOWN;
+	                } else {
+	                        *w = pw_minimized_size;
+	                        *hide_orient = ORIENT_RIGHT;
+	                }
+	                break;
+	        case CORNER_SW:
+	                if (panel->orient == PANEL_HORIZONTAL) {
+	                        *h = pw_minimized_size;
+	                        *hide_orient = ORIENT_DOWN;
+	                } else {
+	                        *w = pw_minimized_size;
+	                        *hide_orient = ORIENT_LEFT;
+	                }
+	                break;
+	        case CORNER_NW:
+	                if (panel->orient == PANEL_HORIZONTAL) {
+	                        *h = pw_minimized_size;
+	                        *hide_orient = ORIENT_UP;
+	                } else {
+	                        *w = pw_minimized_size;
+	                        *hide_orient = ORIENT_LEFT;
+	                }
+	                break;
+	        } /* case */ 
+	} else {
+	        switch(corner->pos) {
+	        case CORNER_NE:
+	                if(panel->orient == PANEL_HORIZONTAL) {
+		                *w = basep->hidebutton_w->allocation.width;
+				*hide_orient = ORIENT_RIGHT;
+			} else {
+				*h = basep->hidebutton_s->allocation.height;
+				*hide_orient = ORIENT_UP;
+			}
+		        break;
+		case CORNER_SE:
+		        if(panel->orient == PANEL_HORIZONTAL) {
+				*w = basep->hidebutton_w->allocation.width;
+			        *hide_orient = ORIENT_RIGHT;
+		        } else {
+				*h = basep->hidebutton_n->allocation.height;
+			        *hide_orient = ORIENT_DOWN;
+		        }
+		        break;
+	        case CORNER_SW:
+		        if(panel->orient == PANEL_HORIZONTAL) {
+				*w = basep->hidebutton_e->allocation.width;
+			        *hide_orient = ORIENT_LEFT;
+		        } else {
+				*h = basep->hidebutton_n->allocation.height;
+			        *hide_orient = ORIENT_DOWN;
+		        }
+		        break;
+	        case CORNER_NW:
+			if(panel->orient == PANEL_HORIZONTAL) {
+				*w = basep->hidebutton_e->allocation.width;
+			        *hide_orient = ORIENT_LEFT;
+		        } else {
+				*h = basep->hidebutton_s->allocation.height;
+			        *hide_orient = ORIENT_UP;
+		        }
+		        break;
+	        } /* case */
 	}
 	/*just sanity checking*/
 	if(*w<1) *w=1;
@@ -251,18 +292,27 @@ corner_widget_get_pos(CornerWidget *corner, gint16 *x, gint16 *y, int width, int
 		   corner->state == CORNER_HIDDEN)
 			*x = gdk_screen_width() -
 				BASEP_WIDGET(corner)->hidebutton_w->allocation.width;
+		else if(corner->state == CORNER_AUTO_HIDDEN &&
+			panel->orient == PANEL_VERTICAL)
+		        *x = gdk_screen_width() - pw_minimized_size;
 		break;
 	case CORNER_SE:
 		*x = gdk_screen_width() - width;
 		*y = gdk_screen_height() - height;
-		if(panel->orient == PANEL_HORIZONTAL &&
-		   corner->state == CORNER_HIDDEN)
-			*x = gdk_screen_width() -
-				BASEP_WIDGET(corner)->hidebutton_w->allocation.width;
-		else if(panel->orient == PANEL_VERTICAL &&
-			corner->state == CORNER_HIDDEN)
-			*y = gdk_screen_height() -
-				BASEP_WIDGET(corner)->hidebutton_n->allocation.height;
+		if(corner->state == CORNER_HIDDEN) {
+		        if(panel->orient == PANEL_HORIZONTAL)
+		                *x = gdk_screen_width() -
+			             BASEP_WIDGET(corner)->hidebutton_w->allocation.width;
+		        else if(panel->orient == PANEL_VERTICAL)
+		                *y = gdk_screen_height() -
+		                     BASEP_WIDGET(corner)->hidebutton_n->allocation.height;
+		}
+		else if(corner->state == CORNER_AUTO_HIDDEN) {
+  		        if (panel->orient == PANEL_HORIZONTAL) 
+		                *y = gdk_screen_height() - pw_minimized_size;
+			else if (panel->orient == PANEL_VERTICAL)
+			        *x = gdk_screen_width() - pw_minimized_size;
+		}
 		break;
 	case CORNER_SW:
 		*y = gdk_screen_height() - height;
@@ -270,6 +320,9 @@ corner_widget_get_pos(CornerWidget *corner, gint16 *x, gint16 *y, int width, int
 		   corner->state == CORNER_HIDDEN)
 			*y = gdk_screen_height() -
 				BASEP_WIDGET(corner)->hidebutton_n->allocation.height;
+		else if (panel->orient == PANEL_HORIZONTAL &&
+			 corner->state == CORNER_AUTO_HIDDEN)
+		        *y = gdk_screen_height() - pw_minimized_size;
 		break;
 	case CORNER_NW:
 		break;
@@ -338,6 +391,128 @@ corner_widget_set_initial_pos(CornerWidget *corner)
 	gtk_widget_set_uposition(GTK_WIDGET(corner),x,y);
 }
 
+void
+corner_widget_pop_up(CornerWidget *corner)
+{
+	if ((corner->mode != CORNER_AUTO_HIDE) ||
+	    (corner->state == CORNER_MOVING) ||
+	    (corner->state == CORNER_HIDDEN) ||
+	    (corner->state == CORNER_SHOWN))
+		return;
+
+	if(GTK_WIDGET_REALIZED(corner)) {
+		PanelWidget *panel = PANEL_WIDGET(BASEP_WIDGET(corner)->panel);
+		/* PanelOrientType orient = (panel->orient == PANEL_HORIZONTAL) ?  */
+                corner->state = CORNER_MOVING;
+    
+		switch (corner->pos) {
+		case CORNER_NE:
+		        basep_widget_do_showing(BASEP_WIDGET(corner),
+						(panel->orient == PANEL_HORIZONTAL) ? 
+						ORIENT_UP : ORIENT_RIGHT,
+						pw_minimized_size,
+						pw_auto_step);
+                        break;
+               case CORNER_SE:
+                        basep_widget_do_showing(BASEP_WIDGET(corner),
+						(panel->orient == PANEL_HORIZONTAL) ?
+						ORIENT_DOWN : ORIENT_RIGHT,
+						pw_minimized_size,
+						pw_auto_step);
+                        break;
+               case CORNER_SW:
+                        basep_widget_do_showing(BASEP_WIDGET(corner),
+						(panel->orient == PANEL_HORIZONTAL) ?
+						ORIENT_DOWN : ORIENT_LEFT,
+						pw_minimized_size,
+						pw_auto_step);
+                        break;
+               case CORNER_NW:
+                        basep_widget_do_showing(BASEP_WIDGET(corner),
+						(panel->orient == PANEL_HORIZONTAL) ?
+						ORIENT_UP : ORIENT_LEFT,
+						pw_minimized_size,
+						pw_auto_step);
+                        break;
+      
+                }
+        }
+     
+	corner->state = CORNER_SHOWN;
+	gtk_signal_emit(GTK_OBJECT(corner),
+			corner_widget_signals[STATE_CHANGE_SIGNAL],
+			CORNER_SHOWN);
+  
+}
+  
+static int
+corner_widget_pop_down(gpointer data)
+{
+        static const char *supinfo[] = {"panel", "collapse", NULL};
+        CornerWidget *corner = data;
+        if (corner->autohide_inhibit)
+                return TRUE;
+
+        if (corner->state != CORNER_SHOWN ||
+	    panel_widget_is_cursor(PANEL_WIDGET(BASEP_WIDGET(corner)->panel), 0)) {
+	        corner->leave_notify_timer_tag = 0;
+                return FALSE;
+        }
+
+        /*we are moving, or have drawers open, so wait with the
+	  pop_down*/
+        if (panel_applet_in_drag || corner->drawers_open>0)
+                return TRUE;
+
+        gnome_triggers_vdo("", NULL, supinfo);
+
+        gtk_signal_emit(GTK_OBJECT(corner),
+			corner_widget_signals[STATE_CHANGE_SIGNAL],
+			CORNER_AUTO_HIDDEN);
+
+        if(GTK_WIDGET_REALIZED(corner)) {
+	        PanelWidget *panel = PANEL_WIDGET(BASEP_WIDGET(corner)->panel);
+		corner->state = CORNER_MOVING;
+    
+		switch (corner->pos) {
+		case CORNER_NE:
+		        basep_widget_do_hiding(BASEP_WIDGET(corner),
+					       (panel->orient == PANEL_HORIZONTAL) ?
+					       ORIENT_UP : ORIENT_RIGHT,
+					       pw_minimized_size,
+					       pw_auto_step);
+			break;
+		case CORNER_SE:
+		        basep_widget_do_hiding(BASEP_WIDGET(corner),
+					       (panel->orient == PANEL_HORIZONTAL) ?
+					       ORIENT_DOWN : ORIENT_RIGHT,
+					       pw_minimized_size,
+					       pw_auto_step);
+			break;
+		case CORNER_SW:
+		        basep_widget_do_hiding(BASEP_WIDGET(corner),
+					       (panel->orient == PANEL_HORIZONTAL) ?
+					       ORIENT_DOWN : ORIENT_LEFT,
+					       pw_minimized_size,
+					       pw_auto_step);
+			break;
+		case CORNER_NW:
+ 		        basep_widget_do_hiding(BASEP_WIDGET(corner),
+					       (panel->orient == PANEL_HORIZONTAL) ?
+					       ORIENT_UP : ORIENT_LEFT,
+					       pw_minimized_size,
+					       pw_auto_step);
+			break;
+		}
+	}
+	corner->state = CORNER_AUTO_HIDDEN;
+  
+	corner->leave_notify_timer_tag = 0;
+  
+	return FALSE;
+}
+      
+
 static void
 corner_widget_pop_show(CornerWidget *corner, int fromright)
 {
@@ -510,18 +685,23 @@ corner_show_hide_right(GtkWidget *widget, gpointer data)
 	CornerWidget *corner = data;
 	gtk_widget_set_state(widget,GTK_STATE_NORMAL);
 	gtk_widget_queue_draw(widget);
-	if(corner->state == CORNER_MOVING) 
-		return FALSE;
-	else if(corner->state == CORNER_SHOWN) {
-		if(!is_right(corner))
-			corner_widget_pop_hide(corner,TRUE);
-		else
-			jump_to_opposite(corner);
-	} else {
+	switch (corner->state) {
+	case CORNER_MOVING:
+		break;
+	case CORNER_SHOWN:
+	        if(!is_right(corner))
+	                corner_widget_pop_hide(corner,TRUE);
+	        else
+	                jump_to_opposite(corner);
+	        break;
+	case CORNER_HIDDEN:
 		if(is_right(corner))
 			corner_widget_pop_show(corner,FALSE);
 		else
 			jump_to_opposite(corner);
+		break;
+	case CORNER_AUTO_HIDDEN:
+	        break; 
 	}
 	return FALSE;
 }
@@ -532,22 +712,80 @@ corner_show_hide_left(GtkWidget *widget, gpointer data)
 	CornerWidget *corner = data;
 	gtk_widget_set_state(widget,GTK_STATE_NORMAL);
 	gtk_widget_queue_draw(widget);
-	if(corner->state == CORNER_MOVING) 
-		return FALSE;
-	else if(corner->state == CORNER_SHOWN) {
+	switch (corner->state) {
+	case CORNER_MOVING:
+		break;
+	case CORNER_SHOWN:
 		if(is_right(corner))
 			corner_widget_pop_hide(corner,FALSE);
 		else
 			jump_to_opposite(corner);
-	} else {
+		break;
+	case CORNER_HIDDEN:
 		if(!is_right(corner))
 			corner_widget_pop_show(corner,TRUE);
 		else
 			jump_to_opposite(corner);
+		break;
+	case CORNER_AUTO_HIDDEN:
+	        break;
 	}
 	return FALSE;
 }
 
+static int
+corner_enter_notify(CornerWidget *corner,
+		    GdkEventCrossing *event,
+		    gpointer data)
+{
+        if ((corner->mode == CORNER_EXPLICIT_HIDE) ||
+	    (event->detail == GDK_NOTIFY_INFERIOR) ||
+	    (corner->state == CORNER_HIDDEN))
+	        return FALSE;
+
+	if (corner->leave_notify_timer_tag != 0) {
+	        gtk_timeout_remove (corner->leave_notify_timer_tag);
+		corner->leave_notify_timer_tag = 0;
+	}
+
+	corner_widget_pop_up(corner);
+    
+	return FALSE;
+}
+
+void
+corner_widget_queue_pop_down(CornerWidget *corner)
+{
+        if ((corner->mode == CORNER_EXPLICIT_HIDE) ||
+	    (corner->state == CORNER_AUTO_HIDDEN) ||
+	    (corner->state == CORNER_HIDDEN))
+	        return;
+
+	/* check if there's already a timeout set, and delete it if 
+	 * there was */
+        if (corner->leave_notify_timer_tag != 0)
+	        gtk_timeout_remove(corner->leave_notify_timer_tag);
+
+	/* set up our delay for popup. */
+	corner->leave_notify_timer_tag = 
+	  gtk_timeout_add (pw_minimize_delay,
+			   corner_widget_pop_down, corner);
+        return;
+}
+
+static int
+corner_leave_notify(CornerWidget *corner,
+		    GdkEventCrossing *event,
+		    gpointer data)
+{
+        if (event->detail == GDK_NOTIFY_INFERIOR) 
+	        return FALSE;
+
+	corner_widget_queue_pop_down(corner);
+  
+	return FALSE;
+}
+
 static void
 corner_widget_set_hidebuttons(BasePWidget *basep)
 {
@@ -579,17 +817,42 @@ corner_widget_set_hidebuttons(BasePWidget *basep)
 	}
 }
 
+static void
+corner_widget_destroy(CornerWidget *corner)
+{
+	/* check if there's a timeout set, and delete it if 
+	 * there was */
+	if (corner->leave_notify_timer_tag != 0)
+		gtk_timeout_remove (corner->leave_notify_timer_tag);
+}
+
 static void
 corner_widget_init (CornerWidget *corner)
 {
+	gtk_signal_connect(GTK_OBJECT(corner), "enter_notify_event",
+			   GTK_SIGNAL_FUNC(corner_enter_notify),
+			   NULL);
+	gtk_signal_connect(GTK_OBJECT(corner), "leave_notify_event",
+			   GTK_SIGNAL_FUNC(corner_leave_notify),
+			   NULL);
+	gtk_signal_connect(GTK_OBJECT(corner), "destroy",
+			   GTK_SIGNAL_FUNC(corner_widget_destroy),
+			   NULL);
+
 	corner->pos = CORNER_NE;
+	corner->mode = CORNER_EXPLICIT_HIDE;
 	corner->state = CORNER_SHOWN;
+
+	corner->leave_notify_timer_tag = 0;
+	corner->autohide_inhibit = FALSE;
+	corner->drawers_open = 0;
 }
 
 
 GtkWidget*
 corner_widget_new (CornerPos pos,
 		   PanelOrientation orient,
+		   CornerMode mode,
 		   CornerState state,
 		   int hidebuttons_enabled,
 		   int hidebutton_pixmaps_enabled,
@@ -634,11 +897,22 @@ corner_widget_new (CornerPos pos,
 			   corner);
 
 	corner->pos = pos;
+	corner->mode = mode;
 	if(state != CORNER_MOVING)
 		corner->state = state;
 
+	corner->autohide_inhibit = FALSE;
+
+	/*sanity check ... this is a case which should never happen*/
+	if (corner->mode == CORNER_EXPLICIT_HIDE &&
+	    corner->state == CORNER_AUTO_HIDDEN)
+	        corner->state = CORNER_SHOWN;
+
 	corner_widget_set_initial_pos(corner);
 
+	if (corner->mode == CORNER_AUTO_HIDE)
+  	        corner_widget_queue_pop_down(corner);
+
 	return GTK_WIDGET(corner);
 }
 
@@ -646,6 +920,7 @@ void
 corner_widget_change_params(CornerWidget *corner,
 			    CornerPos pos,
 			    PanelOrientation orient,
+			    CornerMode mode,
 			    CornerState state,
 			    int hidebuttons_enabled,
 			    int hidebutton_pixmaps_enabled,
@@ -654,16 +929,13 @@ corner_widget_change_params(CornerWidget *corner,
 			    int fit_pixmap_bg,
 			    GdkColor *back_color)
 {
-	CornerPos oldpos;
+  
+        CornerPos oldpos;
 	CornerState oldstate;
-	
-	g_return_if_fail(corner);
-	g_return_if_fail(GTK_WIDGET_REALIZED(GTK_WIDGET(corner)));
-
-	oldpos = corner->pos;
-	corner->pos = pos;
-	oldstate = corner->state;
-	corner->state = state;
+	CornerMode oldmode;
+  
+        g_return_if_fail(corner);
+        g_return_if_fail(GTK_WIDGET_REALIZED(GTK_WIDGET(corner)));
 
 	/*avoid flicker during size_request*/
 	if(PANEL_WIDGET(BASEP_WIDGET(corner)->panel)->orient != orient)
@@ -677,16 +949,52 @@ corner_widget_change_params(CornerWidget *corner,
 				   pixmap_name,
 				   fit_pixmap_bg,
 				   back_color);
+
+	if (corner->mode == CORNER_EXPLICIT_HIDE && 
+	    corner->state == CORNER_AUTO_HIDDEN) {
+		corner->state = CORNER_SHOWN;
+	}
 	
+	oldpos = corner->pos;
+	corner->pos = pos;
 	if(oldpos != corner->pos)
 	   	gtk_signal_emit(GTK_OBJECT(corner),
 	   			corner_widget_signals[POS_CHANGE_SIGNAL],
 	   			corner->pos);
-	if(oldstate != corner->state)
+	
+	oldstate = corner->state;
+	corner->state = state;
+	if(state != corner->state)
 	   	gtk_signal_emit(GTK_OBJECT(corner),
 	   			corner_widget_signals[STATE_CHANGE_SIGNAL],
 	   			corner->state);
-	
+
+	oldmode = corner->mode;
+	corner->mode = mode;
+	if (oldmode != corner->mode) {
+	        GtkWidget *wid = GTK_WIDGET(corner);
+		if (corner->mode == CORNER_AUTO_HIDE) {
+		        corner_widget_queue_pop_down(corner);
+			gnome_win_hints_set_hints(wid,
+						  GNOME_PANEL_HINTS);
+			gnome_win_hints_set_layer(wid,
+						  global_config.keep_bottom?
+						  WIN_LAYER_ONTOP:
+						  WIN_LAYER_ABOVE_DOCK);
+		} else {
+		        if (corner->state == CORNER_AUTO_HIDDEN)
+			        corner->state = CORNER_SHOWN;
+			gnome_win_hints_set_hints(wid,
+						  GNOME_PANEL_HINTS |
+						  WIN_HINTS_DO_NOT_COVER);
+			gnome_win_hints_set_layer(wid,
+						  global_config.keep_bottom?
+						  WIN_LAYER_BELOW:
+						  WIN_LAYER_DOCK);
+		}
+	}
+	      
+	    
 	gtk_widget_queue_resize(GTK_WIDGET(corner));
 }
 
@@ -701,6 +1009,7 @@ corner_widget_change_pos_orient(CornerWidget *corner,
 	corner_widget_change_params(corner,
 				    pos,
 				    orient,
+				    corner->mode,
 				    corner->state,
 				    basep->hidebuttons_enabled,
 				    basep->hidebutton_pixmaps_enabled,
