@@ -30,7 +30,7 @@
 
 static char *gnome_folder = NULL;
 
-/*for Red Hat menus to trigger rereading on directory writes*/
+/*for AnotherLevel menus to trigger rereading on directory writes*/
 static time_t rhsysdir_mtime = 0;
 static time_t rhuserdir_mtime = 0;
 
@@ -45,7 +45,7 @@ extern GlobalConfig global_config;
 
 extern int config_sync_timeout;
 extern int panels_to_sync;
-extern GSList *applets_to_sync;
+extern int applets_to_sync;
 extern int globals_to_sync;
 extern int need_complete_save;
 
@@ -1045,7 +1045,7 @@ drag_data_get_menu_cb (GtkWidget *widget, GdkDragContext     *context,
 		       GtkSelectionData   *selection_data, guint info,
 		       guint time, char *item_loc)
 {
-	gchar *uri_list = g_strconcat ("file:", item_loc, NULL);
+	gchar *uri_list = g_strconcat ("file:", item_loc, "\r\n", NULL);
 	gtk_selection_data_set (selection_data,
 				selection_data->target, 8, uri_list,
 				strlen(uri_list));
@@ -1831,6 +1831,8 @@ menu_deactivate(GtkWidget *w, gpointer data)
 	/* allow the panel to hide again */
 	if(IS_SNAPPED_WIDGET(panel))
 		SNAPPED_WIDGET(panel)->autohide_inhibit = FALSE;
+	else if (IS_CORNER_WIDGET(panel))
+	        CORNER_WIDGET(panel)->autohide_inhibit = FALSE;
 	BUTTON_WIDGET(menu->button)->in_button = FALSE;
 	BUTTON_WIDGET(menu->button)->ignore_leave = FALSE;
 	button_widget_up(BUTTON_WIDGET(menu->button));
@@ -1981,6 +1983,7 @@ create_new_panel(GtkWidget *w,gpointer data)
 		find_empty_cpos_cori(&cpos,&cori);
 		panel = corner_widget_new(cpos,
 					  cori,
+					  CORNER_EXPLICIT_HIDE,
 					  CORNER_SHOWN,
 					  TRUE,
 					  TRUE,
@@ -2124,11 +2127,11 @@ create_panel_root_menu(GtkWidget *panel)
 	}
 
 	if(g_file_exists("/etc/X11/wmconfig")) {
-		menu = create_user_menu(_("Red Hat menus"),"apps-redhat",
+		menu = create_user_menu(_("AnotherLevel menus"),"apps-redhat",
 					NULL,TRUE,TRUE,TRUE);
 		if(menu) {
 			menuitem = gtk_menu_item_new ();
-			setup_menuitem (menuitem, 0, _("Red Hat menus"));
+			setup_menuitem (menuitem, 0, _("AnotherLevel menus"));
 			gtk_menu_append (GTK_MENU (panel_menu), menuitem);
 			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
 						   menu);
@@ -2232,7 +2235,9 @@ convert_to_panel(GtkWidget *w, gpointer data)
 
 		cor = (cw->pos%2)?1-current_panel->orient:current_panel->orient;
 		panel = snapped_widget_new((cw->pos+cor)%4,
-					   SNAPPED_EXPLICIT_HIDE,
+					   cw->mode==CORNER_EXPLICIT_HIDE?
+					     SNAPPED_EXPLICIT_HIDE:
+					     SNAPPED_AUTO_HIDE,
 					   SNAPPED_SHOWN,
 					   BASEP_WIDGET(cw)->hidebuttons_enabled,
 					   BASEP_WIDGET(cw)->hidebutton_pixmaps_enabled,
@@ -2254,6 +2259,9 @@ convert_to_panel(GtkWidget *w, gpointer data)
 					  (sw->pos==SNAPPED_TOP ||
 					   sw->pos==SNAPPED_BOTTOM)?
 					  PANEL_HORIZONTAL:PANEL_VERTICAL,
+					  sw->mode==SNAPPED_EXPLICIT_HIDE?
+					    CORNER_EXPLICIT_HIDE:
+					    CORNER_AUTO_HIDE,
 					  CORNER_SHOWN,
 					  BASEP_WIDGET(sw)->hidebuttons_enabled,
 					  BASEP_WIDGET(sw)->hidebutton_pixmaps_enabled,
@@ -2275,6 +2283,7 @@ convert_to_panel(GtkWidget *w, gpointer data)
 		printf("%lX, %d\n",(long)ad->applet,i);
 #endif
 	}
+	gdk_flush();
 	gtk_widget_destroy(pw);
 }
 
@@ -2812,17 +2821,6 @@ create_rh_menu(int dofork)
 	g_free(userrh);
 	mkdir(rhdir,0755);
 	if(rhlist) {
-		if (g_file_exists("/usr/share/icons/mini/mini-redhat.xpm")) {
-			GnomeDesktopEntry dentry = {0};
-			dentry.name = _("Red Hat menus");
-			dentry.type = "Directory";
-			dentry.icon = "/usr/share/icons/mini/mini-redhat.xpm";
-			dentry.location = g_strconcat(rhdir,"/.directory",
-						      NULL);
-			gnome_desktop_entry_save(&dentry);
-			/* free up the dentry + the location */
-			g_free(dentry.location);
-		}
 		make_rh_submenu(rhdir,rhlist);
 
 		g_slist_foreach(rhlist,(GFunc)free_rh_item,NULL);
@@ -2855,7 +2853,7 @@ create_root_menu(int fake_submenus, int flags)
 	}
 	if(flags&MAIN_MENU_REDHAT && !(flags&MAIN_MENU_REDHAT_SUB)) {
 		rh_submenu_to_display(NULL,NULL);
-		root_menu = create_user_menu(_("Red Hat menus"), "apps-redhat",
+		root_menu = create_user_menu(_("AnotherLevel menus"), "apps-redhat",
 					     root_menu, fake_submenus, FALSE,
 					     FALSE);
 		need_separ = TRUE;
@@ -2904,17 +2902,10 @@ create_root_menu(int fake_submenus, int flags)
 		if(need_separ)
 			add_menu_separator(root_menu);
 		need_separ = FALSE;
-		menu = create_user_menu(_("Red Hat menus"), "apps-redhat", 
+		menu = create_user_menu(_("AnotherLevel menus"), "apps-redhat", 
 					NULL, fake_submenus, TRUE, TRUE);
-		if (g_file_exists("/usr/share/icons/mini/mini-redhat.xpm")) {
-			pixmap = gnome_stock_pixmap_widget_at_size (NULL, "/usr/share/icons/mini/mini-redhat.xpm",
-								    SMALL_ICON_SIZE,
-								    SMALL_ICON_SIZE);
-			if (pixmap)
-				gtk_widget_show (pixmap);
-		}
 		menuitem = gtk_menu_item_new ();
-		setup_menuitem (menuitem, pixmap, _("Red Hat menus"));
+		setup_menuitem (menuitem, pixmap, _("AnotherLevel menus"));
 		gtk_menu_append (GTK_MENU (root_menu), menuitem);
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
 		gtk_signal_connect(GTK_OBJECT(menu),"show",
@@ -3002,6 +2993,9 @@ menu_button_pressed(GtkWidget *widget, gpointer data)
 	if(IS_SNAPPED_WIDGET(wpanel)) {
 		SNAPPED_WIDGET(wpanel)->autohide_inhibit = TRUE;
 		snapped_widget_queue_pop_down(SNAPPED_WIDGET(wpanel));
+	} else if (IS_CORNER_WIDGET(wpanel)) {
+	        CORNER_WIDGET(wpanel)->autohide_inhibit = TRUE;
+	        corner_widget_queue_pop_down(CORNER_WIDGET(wpanel));
 	}
 
 	BUTTON_WIDGET(menu->button)->ignore_leave = TRUE;
@@ -3377,7 +3371,7 @@ create_properties_dialog(Menu *menu)
 			      menu->main_menu_flags&MAIN_MENU_USER,
 			      menu->main_menu_flags&MAIN_MENU_USER_SUB);
 	add_menu_type_options(GTK_OBJECT(dialog),GTK_TABLE(table),2,
-			      _("Red Hat menu (if found): "),"redhat",
+			      _("AnotherLevel menu (if found): "),"redhat",
 			      menu->main_menu_flags&MAIN_MENU_REDHAT,
 			      menu->main_menu_flags&MAIN_MENU_REDHAT_SUB);
 	add_menu_type_options(GTK_OBJECT(dialog),GTK_TABLE(table),3,
