@@ -739,20 +739,31 @@ panel_widget_draw_all(PanelWidget *panel, GdkRectangle *area)
 	GtkWidget *widget;
 	GdkGC *gc;
 	GdkPixmap *pixmap;
+	GdkRectangle da;
 
 	g_return_if_fail(panel!=NULL);
 	g_return_if_fail(IS_PANEL_WIDGET(panel));
-	
+
 	widget = GTK_WIDGET(panel);
 
-	if(widget->allocation.width <= 0 ||
-	   widget->allocation.height <= 0 ||
-	   !GTK_WIDGET_DRAWABLE(widget))
+	if(!GTK_WIDGET_DRAWABLE(widget) ||
+	   widget->allocation.width <= 0 ||
+	   widget->allocation.height <= 0)
 		return;
-
+	
+	if(area) {
+		if(area->width==0 || area->height==0)
+			return;
+		da = *area;
+	} else {
+		da.x = 0;
+		da.y = 0;
+		da.width = widget->allocation.width;
+		da.height = widget->allocation.height;
+	}
+	
 	pixmap = gdk_pixmap_new(widget->window,
-				widget->allocation.width,
-				widget->allocation.height,
+				da.width,da.height,
 				gtk_widget_get_visual(widget)->depth);
 	
 	gc = gdk_gc_new(pixmap);
@@ -761,13 +772,10 @@ panel_widget_draw_all(PanelWidget *panel, GdkRectangle *area)
 	if(widget->style->bg_pixmap[GTK_WIDGET_STATE(widget)]) {
 		gdk_gc_set_fill(gc, GDK_TILED);
 		gdk_gc_set_tile(gc, widget->style->bg_pixmap[GTK_WIDGET_STATE(widget)]);
+		gdk_gc_set_ts_origin(gc,-da.x,-da.y);
 	}
 				
-	if(!area)
-		gdk_draw_rectangle(pixmap,gc, TRUE, 0, 0,-1,-1);
-	else
-		gdk_draw_rectangle(pixmap,gc, TRUE, area->x, area->y,
-				   area->width, area->height);
+	gdk_draw_rectangle(pixmap,gc, TRUE, 0,0,-1,-1);
 
 	gdk_gc_unref(gc);
 
@@ -776,21 +784,13 @@ panel_widget_draw_all(PanelWidget *panel, GdkRectangle *area)
 		AppletData *ad = li->data;
 		if(IS_BUTTON_WIDGET(ad->applet) &&
 		   (!area || gtk_widget_intersect(ad->applet, area, NULL)))
-				button_widget_draw(BUTTON_WIDGET(ad->applet),
-						   pixmap);
+			button_widget_draw(BUTTON_WIDGET(ad->applet),
+					   pixmap,da.x,da.y);
 	}
-	if(!area)
-		gdk_draw_pixmap(widget->window,
-				widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
-				pixmap,
-				0,0,0,0,-1,-1);
-	else
-		gdk_draw_pixmap(widget->window,
-				widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
-				pixmap,
-				area->x,area->y,
-				area->x,area->y,
-				area->width,area->height);
+	gdk_draw_pixmap(widget->window,
+			widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
+			pixmap,
+			0,0,da.x,da.y,da.width,da.height);
 	gdk_pixmap_unref(pixmap);
 }
 
@@ -893,6 +893,7 @@ static int
 fit_pix_timeout_top(gpointer data)
 {
 	PanelWidget *panel = data;
+	panel->pixmap_resize_timeout_top = 0;
 	if(panel->pixmap_resize_timeout ||
 	   !panel->fit_pixmap_bg ||
 	   panel->back_type != PANEL_BACK_PIXMAP)
@@ -1035,7 +1036,10 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		if(panel->pixmap_resize_timeout)
 			panel->pixmap_resize_pending = TRUE;
 		else {
-			gtk_timeout_add(500,fit_pix_timeout_top,panel);
+			if(panel->pixmap_resize_timeout_top)
+				gtk_timeout_remove(panel->pixmap_resize_timeout_top);
+			panel->pixmap_resize_timeout_top = 
+				gtk_timeout_add(500,fit_pix_timeout_top,panel);
 		}
 	}
 
@@ -1305,6 +1309,7 @@ static void
 panel_widget_destroy(GtkWidget *w, gpointer data)
 {
 	GdkImlibImage *im;
+	PanelWidget *panel = PANEL_WIDGET(w);
 
 	g_return_if_fail(w!=NULL);
 	g_return_if_fail(IS_PANEL_WIDGET(w));
@@ -1315,6 +1320,11 @@ panel_widget_destroy(GtkWidget *w, gpointer data)
 	
 	/*remove from panels list*/
 	panels = g_slist_remove(panels,w);
+
+	if(panel->pixmap_resize_timeout)
+		gtk_timeout_remove(panel->pixmap_resize_timeout);
+	if(panel->pixmap_resize_timeout_top)
+		gtk_timeout_remove(panel->pixmap_resize_timeout_top);
 }
 
 static int panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data);
@@ -1378,6 +1388,7 @@ panel_widget_init (PanelWidget *panel)
 	panel->back_type =PANEL_BACK_NONE;
 	panel->fit_pixmap_bg = FALSE;
 	panel->pixmap_resize_timeout = 0;
+	panel->pixmap_resize_timeout_top = 0;
 	panel->pixmap_resize_pending = FALSE;
 	panel->back_pixmap = NULL;
 	panel->back_color.red = 0;
