@@ -13,7 +13,7 @@ GlobalConfig temp_config;
 extern GlobalConfig global_config;
 extern int config_sync_timeout;
 extern int panels_to_sync;
-extern GSList *applets_to_sync;
+extern int applets_to_sync;
 extern int globals_to_sync;
 extern int need_complete_save;
 
