@@ -15,7 +15,7 @@
 #include "panel-include.h"
 
 int config_sync_timeout = 0;
-GSList *applets_to_sync = NULL;
+int applets_to_sync = FALSE;
 int panels_to_sync = FALSE;
 int globals_to_sync = FALSE;
 int need_complete_save = FALSE;
@@ -369,6 +369,7 @@ save_panel_configuration(gpointer data, gpointer user_data)
 		CornerWidget *corner = CORNER_WIDGET(pd->panel);
 		gnome_config_set_int("pos", corner->pos);
 		gnome_config_set_int("orient",panel->orient);
+		gnome_config_set_int("mode", corner->mode);
 		gnome_config_set_int("state", corner->state);
 		break;
 		}
@@ -403,7 +404,7 @@ save_panel_configuration(gpointer data, gpointer user_data)
 static void
 do_session_save(GnomeClient *client,
 		int complete_sync,
-		GSList *sync_applets,
+		int sync_applets,
 		int sync_panels,
 		int sync_globals)
 {
@@ -429,14 +430,10 @@ do_session_save(GnomeClient *client,
 
 	printf("Saving session: 1"); fflush(stdout);
 #endif
-	if(complete_sync) {
+	if(complete_sync || sync_applets) {
 		GSList *li;
 		for(li=applets;li!=NULL;li=g_slist_next(li))
 			save_applet_configuration(li->data);
-	} else {
-		GSList *li;
-		for(li = sync_applets; li!=NULL; li=g_slist_next(li))
-			save_applet_configuration(li->data);
 	}
 #ifdef PANEL_DEBUG
 	printf(" 2"); fflush(stdout);
@@ -532,29 +529,25 @@ panel_config_sync(void)
 	   applets_to_sync ||
 	   panels_to_sync ||
 	   globals_to_sync) {
-		GSList *_applets_to_sync = applets_to_sync;
-
-		applets_to_sync = NULL;
 		if (!(gnome_client_get_flags(client) & 
 		      GNOME_CLIENT_IS_CONNECTED)) {
 			do_session_save(client,need_complete_save,
-					_applets_to_sync,panels_to_sync,
+					applets_to_sync,panels_to_sync,
 					globals_to_sync);
 			need_complete_save = FALSE;
+			applets_to_sync = FALSE;
 			panels_to_sync = FALSE;
 			globals_to_sync = FALSE;
-			g_slist_free(_applets_to_sync);
 		} else {
 			/*prevent possible races by doing this before requesting
 			  save*/
 			need_complete_save = FALSE;
+			applets_to_sync = FALSE;
 			panels_to_sync = FALSE;
 			globals_to_sync = FALSE;
-			g_slist_free(_applets_to_sync);
 			gnome_client_request_save (client, GNOME_SAVE_LOCAL, FALSE,
 						   GNOME_INTERACT_NONE, FALSE, FALSE);
 		}
-
 	}
 }
 
@@ -574,7 +567,7 @@ panel_session_save (GnomeClient *client,
 		    int is_fast,
 		    gpointer client_data)
 {
-	do_session_save(client,TRUE,NULL,FALSE,FALSE);
+	do_session_save(client,TRUE,FALSE,FALSE,FALSE);
 	/* Always successful.  */
 	return TRUE;
 }
@@ -609,127 +602,21 @@ panel_session_die (GnomeClient *client,
 	return TRUE;
 }
 
-/*save ourselves*/
-static int
-panel_really_logout(GtkWidget *w, int button, gpointer data)
-{
-	GtkWidget **box=data;
-
-	if(button==0) {
-
-	        gnome_triggers_do("Session shutdown", NULL,
-				  "gnome", "logout", NULL);
-	  
-		if (! GNOME_CLIENT_CONNECTED (client)) {
-			panel_session_save (client, 1, GNOME_SAVE_BOTH, 1,
-					    GNOME_INTERACT_NONE, 0, NULL);
-			panel_session_die (client, NULL);
-		} else {
-			/* We request a completely interactive, full,
-			   slow shutdown.  */
-			gnome_client_request_save (client, GNOME_SAVE_BOTH, 1,
-						   GNOME_INTERACT_ANY, 0, 1);
-		}
-	} else if(button==2) {
-		GtkWidget *dlg =
-			gnome_message_box_new(_("Are you sure you want to "
-						"just terminate the panel?\n\n"
-						"If you need to restart the "
-						"panel after terminating it "
-						"here, you will need to type "
-						"panel in a terminal window\n\n"
-						"Press OK to terminate the "
-						"panel!"),
-					      GNOME_MESSAGE_BOX_WARNING,
-					      GNOME_STOCK_BUTTON_OK,
-					      GNOME_STOCK_BUTTON_CANCEL,
-					      NULL);
-		if(gnome_dialog_run_and_close(GNOME_DIALOG(dlg))==0) {
-			gnome_client_set_restart_style (client,
-							GNOME_RESTART_NEVER);
-			panel_session_save (client, 1, GNOME_SAVE_BOTH, 1,
-					    GNOME_INTERACT_NONE, 0, NULL);
-			panel_session_die (client, NULL);
-		}
-	}
-	if(box)
-		*box = NULL;
-
-	return TRUE;
-}
-
-static void
-panel_really_logout_destroy(GtkWidget *w, gpointer data)
-{
-	GtkWidget **box=data;
-	if(box)
-		*box = NULL;
-}
-
-
-static void
-ask_next_time(GtkWidget *w,gpointer data)
-{
-	global_config.prompt_for_logout = GTK_TOGGLE_BUTTON(w)->active!=FALSE;
-	
-	globals_to_sync = TRUE;
-}
-
 /* the logout function */
 void
 panel_quit(void)
 {
-	static GtkWidget *box = NULL;
-	GtkWidget *but = NULL;
-
-	if(!global_config.prompt_for_logout) {
-		panel_really_logout(NULL,0,NULL);
-		return;
-	}
-
-	if(box) {
-		gdk_window_raise(box->window);
-		gtk_widget_show(box);
-		return;
-	}
-
-	box = gnome_message_box_new (_("Really log out?"),
-				     GNOME_MESSAGE_BOX_QUESTION,
-				     GNOME_STOCK_BUTTON_YES,
-				     GNOME_STOCK_BUTTON_NO,
-				     GNOME_CLIENT_CONNECTED (client)?
-				       _("Only terminate panel"):NULL,
-				     NULL);
-	gtk_window_set_wmclass(GTK_WINDOW(box),
-			       "logout_dialog","Panel");
-	gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-	/*gtk_window_set_position(GTK_WINDOW(box), GTK_WIN_POS_CENTER);*/
-	gtk_window_set_policy(GTK_WINDOW(box), FALSE, FALSE, TRUE);
-
-	gtk_signal_connect (GTK_OBJECT (box), "clicked",
-		            GTK_SIGNAL_FUNC (panel_really_logout), &box);
-	gtk_signal_connect (GTK_OBJECT (box), "destroy",
-		            GTK_SIGNAL_FUNC (panel_really_logout_destroy),
-			    &box);
-
-	but = gtk_check_button_new_with_label(_("Ask next time"));
-	gtk_widget_show(but);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(box)->vbox),but,
-		           FALSE, TRUE, GNOME_PAD_SMALL);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(but),TRUE);
-	gtk_signal_connect(GTK_OBJECT(but),"toggled",
-			   GTK_SIGNAL_FUNC(ask_next_time),NULL);
-
-	gtk_widget_show (box);
+  gnome_client_request_save (client, GNOME_SAVE_BOTH, 1,
+			     GNOME_INTERACT_ANY, 0, 1);
 }
 
 static void
 load_default_applets(void)
 {
 	char *def_launchers[] =
-	      { "apps/gnome-help.desktop",
-		"apps/System/gnomecc.desktop",
-		"apps/Applications/Netscape.desktop",
+	      { "gnome/apps/gnome-help.desktop",
+		"gnome/apps/Settings/gnomecc.desktop",
+		"gnome/apps/Applications/Netscape.desktop",
 		NULL };
 	int i;
 	int flags = MAIN_MENU_SYSTEM|MAIN_MENU_USER;
@@ -998,6 +885,7 @@ init_user_panels(void)
 				CornerPos pos;
 				PanelOrientation orient;
 				CornerState state;
+				CornerMode mode;
 				
 				g_string_sprintf(buf,"pos=%d", CORNER_NE);
 				pos=gnome_config_get_int(buf->str);
@@ -1009,8 +897,13 @@ init_user_panels(void)
 				g_string_sprintf(buf,"state=%d", CORNER_SHOWN);
 				state=gnome_config_get_int(buf->str);
 
+				g_string_sprintf(buf,"mode=%d",
+						 CORNER_EXPLICIT_HIDE);
+				mode=gnome_config_get_int(buf->str);
+
 				panel = corner_widget_new(pos,
 							  orient,
+							  mode,
 							  state,
 							  hidebuttons_enabled,
 							  hidebutton_pixmaps_enabled,
