@@ -15,6 +15,7 @@
 #include <X11/Xlib.h>
 
 #include "panel-include.h"
+#include "panel-widget.h"
 
 /* from gtkhandlebox.c */
 #define DRAG_HANDLE_SIZE 10
@@ -219,9 +220,8 @@ ask_about_swallowing(PanelWidget *panel, int pos)
 	gtk_object_set_data(GTK_OBJECT(d),"panel",panel);
 	gtk_object_set_data(GTK_OBJECT(d),"pos",GINT_TO_POINTER(pos));
 
-	box = gtk_hbox_new(FALSE,5);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),box,
-			   TRUE,TRUE,5);
+	box = gtk_hbox_new(FALSE,GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),box, TRUE,TRUE,0);
 	w = gtk_label_new(_("Title of application to swallow"));
 	gtk_box_pack_start(GTK_BOX(box),w,FALSE,FALSE,0);
 	w = gnome_entry_new("swallow_title");
@@ -230,9 +230,8 @@ ask_about_swallowing(PanelWidget *panel, int pos)
 	gtk_signal_connect(GTK_OBJECT(title_e),"activate",
 			   GTK_SIGNAL_FUNC(act_really_add_swallow),d);
 
-	box = gtk_hbox_new(FALSE,5);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),box,
-			   TRUE,TRUE,5);
+	box = gtk_hbox_new(FALSE,GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),box, TRUE,TRUE,0);
 	w = gtk_label_new(_("Command (optional)"));
 	gtk_box_pack_start(GTK_BOX(box),w,FALSE,FALSE,0);
 	w = gnome_file_entry_new("execute",_("Browse"));
@@ -241,27 +240,26 @@ ask_about_swallowing(PanelWidget *panel, int pos)
 	gtk_signal_connect(GTK_OBJECT(exec_e),"activate",
 			   GTK_SIGNAL_FUNC(act_really_add_swallow),d);
 
-	box = gtk_hbox_new(FALSE,5);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),box,
-			   TRUE,TRUE,5);
+	box = gtk_hbox_new(FALSE,GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),box, TRUE,TRUE,0);
 
 	w = gtk_label_new(_("Width"));
 	gtk_box_pack_start(GTK_BOX(box),w,FALSE,FALSE,0);
 	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 255.0, 1.0,
 						    5.0, 0.0);
-	gtk_adjustment_set_value(adj, 48.0); 
+	gtk_adjustment_set_value(adj, PANEL_MINIMUM_WIDTH); 
 	width_s = gtk_spin_button_new(adj,0,0);
 	gtk_box_pack_start(GTK_BOX(box),width_s,FALSE,FALSE,0);
 
 
 	i_box =gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(box), i_box, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(box), i_box, FALSE, FALSE, GNOME_PAD_SMALL);
 	
 	w = gtk_label_new(_("Height"));
 	gtk_box_pack_start(GTK_BOX(box),w,FALSE,FALSE,0);
 	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 255.0, 1.0,
 						    5.0, 0.0);
-	gtk_adjustment_set_value(adj, 48.0); 
+	gtk_adjustment_set_value(adj, PANEL_MINIMUM_WIDTH); 
 	height_s = gtk_spin_button_new(adj,0,0);
 	gtk_box_pack_start(GTK_BOX(box),height_s,FALSE,FALSE,0);
 	
